@@ -19,6 +19,21 @@ from function_scheduling_distributed_framework.factories.consumer_factory import
 from function_scheduling_distributed_framework.utils import nb_print, patch_print, LogManager, LoggerMixin
 
 
+class BrokerEnum:
+    RABBITMQ_PIKA = 0
+    RABBITMQ_RABBITPY = 1
+    REDIS = 2
+    LOCAL_PYTHON_QUEUE = 3
+    RABBITMQ_AMQPSTORM = 4
+    MONGOMQ = 5
+    PERSISTQUEUE = 6
+    NSQ = 7
+    KAFKA = 8
+    REDIS_ACK_ABLE = 9
+    SQLACHEMY = 10
+    ROCKETMQ = 11
+
+
 def run_many_consumer_by_init_params(consumer_init_params_list: List[dict]):
     for consumer_init_params in consumer_init_params_list:
         get_consumer(**consumer_init_params).start_consuming_message()
@@ -66,6 +81,7 @@ def task_deco(queue_name, *, function_timeout=0, threads_num=50,
 
     for i in range(10, 20):
         f.pub(dict(a=i, b=i * 2))
+        f.push(i, i * 2)
     f.consume()
     '''
 
@@ -92,6 +108,7 @@ def task_deco(queue_name, *, function_timeout=0, threads_num=50,
         func.start_consuming_message = func.consume = func.start = consumer.start_consuming_message
         func.publisher = consumer.publisher_of_same_queue
         func.publish = func.pub = consumer.publisher_of_same_queue.publish
+        func.push = func.delay = consumer.publisher_of_same_queue.push
         func.clear = func.clear_queue = consumer.publisher_of_same_queue.clear
 
         # @functools.wraps(func)
@@ -132,6 +149,8 @@ class IdeAutoCompleteHelper(LoggerMixin):
            for i in range(100, 200):
                f.pub(dict(a=i, b=i * 2))  # f.sub方法是强行用元编程加到f上去的，是运行时状态，pycharm只能补全非运行时态的静态东西。
                IdeAutoCompleteHelper(f).pub({'a': i * 3, 'b': i * 4})  # 和上面的发布等效，但可以自动补全方法名字和入参。
+               f.push(a=i, b=i * 2)
+               IdeAutoCompleteHelper(f).delay(i * 3,  i * 4)
 
            IdeAutoCompleteHelper(f).start_consuming_message()  # 和 f.consume()等效
 
@@ -139,8 +158,9 @@ class IdeAutoCompleteHelper(LoggerMixin):
         self.consuming_func_decorated = consuming_func_decorated
 
         self.consumer = consuming_func_decorated.consumer  # type: AbstractConsumer
-        self.start_consuming_message = self.consume = self.start = consuming_func_decorated.consume = self.consumer.start_consuming_message
+        self.start_consuming_message = self.consume = self.start = self.consumer.start_consuming_message
 
         self.publisher = consuming_func_decorated.publisher  # type: AbstractPublisher
-        self.publish = self.pub = consuming_func_decorated.pub = self.publisher.publish
+        self.publish = self.pub = self.publisher.publish
+        self.push = self.delay = self.publisher.push
         self.clear = self.clear_queue = self.consumer.publisher_of_same_queue.clear = self.publisher.clear
