@@ -17,6 +17,7 @@ from nb_log import LoggerLevelSetterMixin, LogManager, LoggerMixin
 from function_scheduling_distributed_framework.utils import decorators, RedisMixin
 from function_scheduling_distributed_framework import frame_config
 
+
 class RedisAsyncResult(RedisMixin):
     def __init__(self, task_id, timeout=120):
         self.task_id = task_id
@@ -77,10 +78,14 @@ class PublishParamsChecker(LoggerMixin):
         self.all_arg_name_set = set(spec.args)
         if spec.defaults:
             len_deafult_args = len(spec.defaults)
-            self.position_arg_name_set = set(spec.args[0:len_deafult_args])
-            self.keyword_arg_name_set = set(spec.args[-len_deafult_args:])
+            self.position_arg_name_list = spec.args[0:len_deafult_args]
+            self.position_arg_name_set = set(self.position_arg_name_list)
+            self.keyword_arg_name_list = spec.args[-len_deafult_args:]
+            self.keyword_arg_name_set = set(self.keyword_arg_name_list)
         else:
-            self.position_arg_name_set = set(spec.args)
+            self.position_arg_name_list = spec.args
+            self.position_arg_name_set = set(self.position_arg_name_list)
+            self.keyword_arg_name_list = []
             self.keyword_arg_name_set = set()
         self.logger.info(f'{func} 函数的入参要求是 全字段 {self.all_arg_name_set} ,必须字段为 {self.position_arg_name_set} ')
 
@@ -118,7 +123,7 @@ class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         self.logger = LogManager(logger_name).get_logger_and_add_handlers(log_level_int,
                                                                           log_filename=f'{logger_name}.log' if is_add_file_handler else None,
                                                                           formatter_template=frame_config.NB_LOG_FORMATER_INDEX_FOR_CONSUMER_AND_PUBLISHER,
-        )  #
+                                                                          )  #
         self.publish_params_checker = PublishParamsChecker(consuming_function) if consuming_function else None
         # self.rabbit_client = RabbitMqFactory(is_use_rabbitpy=is_use_rabbitpy).get_rabbit_cleint()
         # self.channel = self.rabbit_client.creat_a_channel()
@@ -172,6 +177,32 @@ class AbstractPublisher(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
             self._init_count()
         return RedisAsyncResult(task_id)
 
+    def push(self, *func_args, **func_kwargs):
+        """
+        简写，只支持传递消费函数的本身参数，不支持priority_control_config参数。
+        类似于 publish和push的关系类似 apply_async 和 delay的关系。前者更强大，后者更简略。
+
+        例如消费函数是
+        def add(x,y):
+            print(x+y)
+
+        publish({"x":1,'y':2}) 和 push(1,2)是等效的。但前者可以传递priority_control_config参数。后者只能穿add函数所接受的入参。
+        :param func_args:
+        :param func_kwargs:
+        :return:
+        """
+        # print(func_args,func_kwargs)
+        msg_dict = func_kwargs
+        # print(msg_dict)
+        # print(self.publish_params_checker.position_arg_name_list)
+        # print(func_args)
+        for index, arg in enumerate(func_args):
+            msg_dict[self.publish_params_checker.position_arg_name_list[index]] = arg
+        # print(msg_dict)
+        self.publish(msg_dict)
+
+    delay = push  # 那就来个别名吧，两者都可以。
+
     @abc.abstractmethod
     def concrete_realization_of_publish(self, msg):
         raise NotImplementedError
